class LanguageElements:
    """
    This class contains language elements used for localization
    and internationalization in the application.
    """

    # Help Page Texts
    HELP_TITLE = "Help"
    HELP_UNAVAILABLE = "Help content is unavailable."
